API docs for “spamfighter.core.model.thomas”

# Module s.c.m.thomas

Part of spamfighter.core.model View Source

No module docstring

Class | BayesData | Undocumented
Class | Bayes | No class docstring; 11/25 methods documented
Class | Tokenizer | A simple regex-based whitespace tokenizer.
Function | chi2P | return P(chisq >= chi, with df degree of freedom)

def chi2P(chi, df): (source)
return P(chisq >= chi, with df degree of freedom)

df must be even